@@ -28,9 +28,6 @@
 
 #include "setting.h"
 /*----------------------------------------------------------------------------*/
-void
-js_json_string_to_settings (const char *s_jbuff,
-                            Setting    *st_settings);
 /**
  * @brief  Get settings data from file.
  *
@@ -47,9 +44,9 @@ Setting * js_settings_read (const char *s_fname,
                             __attribute__ ((nonnull (1)));
 /*----------------------------------------------------------------------------*/
 /**
- * @fn  char * js_settings_check_for_update  (Setting     *st_settings,
- *                                            const char  *s_fname,
- *                                            int         *i_err)
+ * @fn  char * js_settings_check_for_update  (const Setting *st_settings,
+ *                                            const char    *s_fname,
+ *                                            int           *i_err)
  *
  * @brief  Check if settings in list are an update to settings stored in
  *         settings file.
@@ -68,7 +65,7 @@ Setting * js_settings_read (const char *s_fname,
  *
  * @fn  int js_settings_update_file (const char *s_buff, const char *s_fname)
  *
- * @brief  Update file with new data
+ * @brief  Update file with new data.
  *
  * @param[in]  s_buff   String with data to save
  * @param[in]  s_fname  File name to save data
@@ -88,17 +85,17 @@ Setting * js_settings_read (const char *s_fname,
  * @return     Saving file status, ERR_OK or error code
  */
 /*----------------------------------------------------------------------------*/
-char * js_settings_check_for_update  (Setting     *st_settings,
-                                      const char  *s_fname,
-                                      int         *i_err)
+char * js_settings_check_for_update  (const Setting *st_settings,
+                                      const char    *s_fname,
+                                      int           *i_err)
                                       __attribute__ ((nonnull (2)));
 
-int    js_settings_update_file       (const char  *s_buff,
-                                      const char  *s_fname)
+int    js_settings_update_file       (const char    *s_buff,
+                                      const char    *s_fname)
                                       __attribute__ ((nonnull (1, 2)));
 
-int    js_settings_check_update_file (Setting    *st_settings,
-                                      const char *s_fname)
+int    js_settings_check_update_file (const Setting *st_settings,
+                                      const char    *s_fname)
                                       __attribute__ ((nonnull (2)));
 /*----------------------------------------------------------------------------*/
 #endif
