@@ -25,26 +25,26 @@
 #define WEBWALLHAVEN_H
 
 #include <gtk/gtk.h>
-#include "fourstrings.h"
+#include "nstrings.h"
 #include "webwidget_s.h"
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Search in Wallhaven database.
  *
  * @param[in,out] ww_widget  WebWidget with widgets and search data
- * @param[in]     fs_data    Four strings with API keys
+ * @param[in]     ns_data    N strings with API keys
  * @return        none
  */
-void wallhaven_search          (WebWidget         *ww_widget,
-                                const FourStrings *fs_data);
+void   wallhaven_search           (WebWidget      *ww_widget,
+                                   const NStrings *ns_data);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Dialog with Wallhaven service settings.
  *
- * @param[in,out] fs_data  Four strings to get and write API keys
+ * @param[in,out] ns_data  N strings to get and write API keys
  * @return        Dialog response
  */
-int  wallhaven_settings_dialog (FourStrings       *fs_data);
+int    wallhaven_settings_dialog    (NStrings     *ns_data);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Options for image search dialog.
@@ -53,7 +53,7 @@ int  wallhaven_settings_dialog (FourStrings       *fs_data);
  * @return        String with image options. After use it should be freed
  *                using free.
  */
-char *  wallhaven_search_opts_dialog (WebWidget         *ww_widget);
+char * wallhaven_search_opts_dialog (WebWidget    *ww_widget);
 /*----------------------------------------------------------------------------*/
 #endif 
 
